#!/bin/bash

# setupfuncs.sh

FILENAME=$1
shift

USAGE="Usage: $FILENAME [ -D macroname ]"

ERRFILE="${FILENAME}.err"

# ----------------------------------------------------------------------- #
# Validate command line options                                           #
# ----------------------------------------------------------------------- #

while getopts ":D:V:" ARG_STRING
do
    case $ARG_STRING in
    D)	MACRODEF=$OPTARG
	;;
    V)	VERSION=$OPTARG
	;;
    *)	echo $USAGE
	exit;;
    esac
done

if [ $MACRODEF ]
then
    case $MACRODEF in
    SCORE) 
	SCORETYPE=
	EXTRAOPTS="-b .8"
	;;
    URTEXT) 
	SCORETYPE=u
	EXTRAOPTS="-b .8"
	;;
    FLAUTO) 
	SCORETYPE=fl
	;;
    BASSO) 
	SCORETYPE=bs
	;;
    *)  
	echo Macronames: SCORE, URTEXT, FLAUTO, BASSO
	exit;;
    esac
fi

if [ $VERSION ]
then
    case $VERSION in
    PARIS) 
	EXTRAOPTS="${EXTRAOPTS} -D PARIS"
	;;
    *)  
	echo Versions: PARIS
	exit;;
    esac
fi

# ----------------------------------------------------------------------- #
# Define functions                                                        #
# ----------------------------------------------------------------------- #

muppage() { 
    MUPOPTS=""
    PAGE=$2
    INFILE=${1}.mup 
    OUTFILE=${1}${SCORETYPE}p${PAGE}.ps
    if [ "${EXTRAOPTS}" ]; then MUPOPTS="${EXTRAOPTS} "; fi
    MUPOPTS="${MUPOPTS} -D $MACRODEF -o ${PAGE} ${INFILE} -f ${OUTFILE} -e ${ERRFILE}"
    mup ${MUPOPTS} > /dev/null 2>&1 
    if [ $? -gt 0 ] 
    then 
	if [ -s ${ERRFILE} ]
	then
	    cat ${ERRFILE}
	else
	    echo "mup ${MUPOPTS}"
	fi
	exit 
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

epsipage() { 
    PAGE=$2
    INFILE=${1}${SCORETYPE}p${PAGE}.ps
    ps2epsi ${INFILE} > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${INFILE} > /dev/null 2>&1 
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

mkps() { 
    dvips -tletter -e0 -O 4mm,0mm $1.dvi -o $1.ps > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

ps2pdf_letter() { 
    ps2pdf -sPAPERSIZE=letter $1.ps
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

mup2epsi() {
    mup -F $1 > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    ps2epsi ${1}.ps > ${ERRFILE} 2>&1
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
}

domovement() {
    let i=1; let maxp=$1
    while [ $i -le $maxp ]
    do
	muppage $2 $i || exit 1
	epsipage $2 $i || exit 1
	let i=$i+1
    done
}

