#!/bin/bash

# setupfuncs2.sh

FILENAME=$1
shift

USAGE="Usage: $FILENAME [ -D macroname ]"

ERRFILE="${FILENAME}.err"

# ----------------------------------------------------------------------- #
# Validate command line options                                           #
# ----------------------------------------------------------------------- #

while getopts ":D:" ARG_STRING
do
    case $ARG_STRING in
    D)	MACRODEF=$OPTARG
	;;
    *)	echo $USAGE
	exit;;
    esac
done

if [ -n MACRODEF ]
then
    case $MACRODEF in
    SCORE1) 
	SCORETYPE=g
	EXTRAOPTS="-b .8 -D VERSION1"
	;;
    SCORE2) 
	SCORETYPE=s
	EXTRAOPTS="-b .8 -D VERSION2"
	;;
    BOTHVERSIONS) 
	SCORETYPE=bth
	EXTRAOPTS="-b .8 -D URTEXT"
	;;
    GURTEXT) 
	SCORETYPE=gu
	MACRODEF=URTEXT
	EXTRAOPTS="-b .8 -D VERSION1"
	;;
    SURTEXT) 
	SCORETYPE=su
	MACRODEF=URTEXT
	EXTRAOPTS="-b .8 -D VERSION2"
	;;
    BFLAUTO) 
	SCORETYPE=bfl
	MACRODEF=BOTHVERSIONS
	EXTRAOPTS="-b .8 -D FLAUTO"
	;;
    GFLAUTO) 
	SCORETYPE=gfl
	MACRODEF=FLAUTO
	EXTRAOPTS="-b .8 -D VERSION1"
	;;
    SFLAUTO) 
	SCORETYPE=sfl
	MACRODEF=FLAUTO
	EXTRAOPTS="-b .8 -D VERSION2"
	;;
    BBASSO) 
	SCORETYPE=bbs
	MACRODEF=BOTHVERSIONS
	EXTRAOPTS="-b .8 -D BASSO"
	;;
    GBASSO) 
	SCORETYPE=gbs
	MACRODEF=BASSO
	EXTRAOPTS="-b .8 -D VERSION1"
	;;
    SBASSO) 
	SCORETYPE=sbs
	MACRODEF=BASSO
	EXTRAOPTS="-b .8 -D VERSION2"
	;;
    *)  
	echo Macronames: SCORE1, SCORE2, BOTHVERSIONS, GURTEXT, SURTEXT, BFLAUTO, GFLAUTO, SFLAUTO, BBASSO, GBASSO, SBASSO
	exit;;
    esac
fi

# ----------------------------------------------------------------------- #
# Define functions                                                        #
# ----------------------------------------------------------------------- #

muppage() { 
    MUPOPTS=""
    PAGE=$2
    INFILE=${1}.mup 
    OUTFILE=${1}${SCORETYPE}p${PAGE}.ps
    if [ "${EXTRAOPTS}" ]; then MUPOPTS="${EXTRAOPTS} "; fi
    MUPOPTS="${MUPOPTS} -D $MACRODEF -o ${PAGE} -f ${OUTFILE} -e ${ERRFILE} ${INFILE}"
    mup ${MUPOPTS} > /dev/null 2>&1 
    if [ $? -gt 0 ] 
    then 
	if [ -s ${ERRFILE} ]
	then
	    cat ${ERRFILE}
	else
	    echo "mup ${MUPOPTS}"
	fi
	exit 
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

epsipage() { 
    PAGE=$2
    INFILE=${1}${SCORETYPE}p${PAGE}.ps
    ps2epsi ${INFILE} > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${INFILE} > /dev/null 2>&1 
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

mkps() { 
    dvips -tletter -e0 -O 4mm,0mm $1.dvi -o $1.ps > ${ERRFILE} 2>&1 
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

ps2pdf_letter() { 
    ps2pdf -sPAPERSIZE=letter $1.ps
    if [ $? -gt 0 ]
    then
	cat ${ERRFILE}
	exit
    fi
    rm -f ${ERRFILE} > /dev/null 2>&1 
}

domovement() {
    i=1; maxp=$1
    while [ $i -le $maxp ]
    do
	muppage $2 $i || exit 1
	epsipage $2 $i || exit 1
	let i=$i+1
    done
}

