#!/bin/sh

# son2.sh

# In Redhat Fedora 2 force use of Ghostscript 7.03 built from source

export PATH="/usr/local/gs7.03/bin:$PATH"

# Generate score with b.c. arrangement from TeX produced front 
# page, comments etc and single .epsi pages from mup sources

# ----------------------------------------------------------------------- #
# Define functions                                                        #
# ----------------------------------------------------------------------- #

. setupfuncs.sh son2.sh -D SCORE -V PARIS

# ----------------------------------------------------------------------- #
# Main program                                                            #
# ----------------------------------------------------------------------- #

# Make temporary symlinks from Sonata 4 mup source files

echo symlinking Sonata 4 source files ...

ln -sf son41.mup son21.mup
ln -sf son42.mup son22.mup
ln -sf son43.mup son23.mup
ln -sf son44.mup son24.mup
 
# Generate single pages from mup sources

# 1st movement, 2 pages

echo 1st movement, generating single pages ...

domovement 2 son21

# 2nd movement, 3 pages

echo 2nd movement, generating single pages ...

domovement 3 son22

# 3rd movement, 1 page

echo 3rd movement, generating single pages ...

domovement 1 son23

# 4th movement, 2 pages

echo 4th movement, generating single pages ...

domovement 2 son24

# Music examples

echo Music example son41_note1

mup2epsi son41_note1

echo Music example son42_note1

mup2epsi son42_note1

echo Music example son43_note1

mup2epsi son43_note1

echo Music example son24_note1

mup2epsi son24_note1

# Remove temporary symlinks from Sonata 4 mup source files

echo Removing symlinked Sonata 4 source files ...

rm -f son21.mup
rm -f son22.mup
rm -f son23.mup
rm -f son24.mup
 
# Process TeX sources including single page .epsi files

echo collecting mup and TeX sources into postscript score ...

tex son2 > ${ERRFILE} 2>&1
if [ $? -gt 0 ]
then
    cat ${ERRFILE}
    exit
fi
rm -f ${ERRFILE} > /dev/null 2>&1 

mkps son2

# Produce pdf file based on .dvi and .epsi files

echo generating pdf file with dvipdfm ...

dvipdfm son2

# Remove .dvi and .epsi files

echo cleaning up ...

rm -f son2*.epsi > /dev/null

rm -f son2.dvi > /dev/null

exit
